DxInterop

Struct DxInterop 

#[non_exhaustive]
pub struct DxInterop { pub gpu_id: GpuLuid, pub device: ID3D11Device, pub cx: Mutex<ID3D11DeviceContext>, }
Direct3D 11 device for storing and sharing overlay texture with other graphics backend.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
gpu_id: GpuLuid

This is the GPU adapter used by the surface. Overlay surface texture must be created with this GPU. Otherwise, surface cannot be rendered.

device: ID3D11Device

Interop Direct3D 11 device.

cx: Mutex<ID3D11DeviceContext>

Interop Direct3D 11 device context.

Implementations

Source

impl DxInterop

pub fn new(adapter: Option<&IDXGIAdapter>) -> Result<Self>

Create new DxInterop.

  • If adapter is provided, it will use provided GPU adapter.
  • If adapter it not provided, it will use system provided GPU adapter.